Class: Aws::Detective::Types::ListOrganizationAdminAccountsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-detective/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#administratorsArray<Types::Administrator>

The list of Detective administrator accounts.



1194
1195
1196
1197
1198
1199
# File 'lib/aws-sdk-detective/types.rb', line 1194

class ListOrganizationAdminAccountsResponse < Struct.new(
  :administrators,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If there are more accounts remaining in the results, then this is the pagination token to use to request the next page of accounts.



1194
1195
1196
1197
1198
1199
# File 'lib/aws-sdk-detective/types.rb', line 1194

class ListOrganizationAdminAccountsResponse < Struct.new(
  :administrators,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end